import { BoxProps } from '@chakra-ui/react';
import { TimeValue } from '@react-types/datepicker';

type TimePickerProps = Omit<BoxProps, "defaultValue"> & {
    /** The label. Defaults to a localized version of "Time" */
    label?: string;
    /** The name of the form field, if used in a regular form */
    name?: string;
    /** The controlled value, if any.
     *
     * A `new Time(hours, minutes)` should be passed
     **/
    value?: TimeValue;
    /** A default value, if any.
     *
     * A `new Time(hours, minutes)` should be passed. Defaults to the current time if not provided.
     **/
    defaultValue?: TimeValue;
    /** Callback for when the time changes */
    onChange?: (value: TimeValue) => void;
    /** The maxiumum number of minutes to move when the step buttons are used.
     *
     * Defaults to 30 minutes.
     *
     * An example: If the time is at 13:37 and the minuteInterval is 15, clicking the step forwards button will move the time to 13:45. Next click will move it to 14:00.
     */
    minuteInterval?: number;
    /** Whether or not the field is disabled */
    isDisabled?: boolean;
};
/** A time picker component.
 *
 * This lets the user select a time of day, either through typing it in, using the up and down arrows to select the hour and minute, or by clicking the step buttons to move the time forwards or backwards in pre-defined increments.
 *
 * ```tsx
 * <TimePicker />
 * ```
 *
 * It can also be controlled:
 *
 * ```tsx
 * <TimePicker value={new Time(13, 37)} onChange={setTime} />
 * ```
 *
 * Note that the TimePicker uses the `Time` class to represent the time. This is a class that is part of the `@internationalized/date` package.
 *
 * @see https://spor.vy.no/komponenter/timepicker
 */
declare const TimePicker: ({ label: externalLabel, value, defaultValue, onChange, minuteInterval, isDisabled: isDisabledExternally, name, ...boxProps }: TimePickerProps) => JSX.Element;

export { TimePicker };
